@@ -1,8 +1,8 @@
 package SOAP::WSDL::SOAP::HeaderFault;
 use strict;
 use warnings;
-use base qw(SOAP::WSDL::Header);
+use base qw(SOAP::WSDL::SOAP::Header);
 
-our $VERSION = $SOAP::WSDL::VERSION;
+our $VERSION = 3.003;
 
-1;
\ No newline at end of file
+1;
