@@ -1,7 +1,7 @@
 package SOAP::WSDL::XSD::Typelib::Builtin::ID;
 use strict;
 use warnings;
-use Class::Std::Storable;
+use Class::Std::Fast::Storable constructor => 'none', cache => 1;
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::NCName);
 
 1;
