@@ -3,10 +3,32 @@ use strict;
 use warnings;
 use Test::Class;
 use base qw(Test::Class);
+
 use File::Basename;
 use File::Spec;
+
 use Test::More;
 
+use Scalar::Util qw(blessed);
+
+our $HAS_TEST_WARN;
+
+BEGIN {
+    $HAS_TEST_WARN = eval { require Test::Warn; import Test::Warn; 1 };
+}
+
+sub has_test_warn {
+    return $HAS_TEST_WARN;
+}
+
+# object accessors
+sub set_object { $_[0]->{ object } = $_[1] }
+sub get_object { return shift->{ object } };
+# class accessors
+sub set_class { $_[0]->{ class } = $_[1] }
+sub get_class { return shift->{ class } };
+
+
 sub startup :Test(startup => 1) {
     my $self = shift;
     my $class = ref $self;
@@ -15,6 +37,7 @@ sub startup :Test(startup => 1) {
         return;
     };
     $class =~s{^Test::}{};
+    $self->set_class( $class );
     use_ok $class;
 }
 
